import React, { useEffect, useState } from 'react';
import Grid from '@material-ui/core/Grid';
import SuccessDialog from '../SuccessDialog';
import productData from './products.json';
import HyperWidget from '../Hyper-Widget';
import { useStyle } from './checkout.styles';
import ProductDetails from './productDetails';
import DesktopLogo from '../Brands/DesktopLogo';
import MobileLogo from '../Brands/mobile-logo@2x.png';
import useProductSelect from './useProductSelect';

function Checkout(props) {

  const {
    location
  } = props;
  
  const classes = useStyle();
  const [widgetFlag, setWidgetFlag] = useState(true);
  const [widgetSize, setWidgetSize] = useState(null);
  const [chargeToken, setTokenForCharge] = useState(null);

  const {
    selectedProduct,
    products,
    selectProductById,
  } = useProductSelect({ dataProvider: productData, location });
   
  window.onHyperWidgetResize = function (size) {
    setWidgetSize({
        width: size.width,
        height: size.height,
    });
  }

  window.onOrderSubmission = function (tokens) {
    setTokenForCharge({
      vaultToken: tokens.vaultToken,
    });
    setWidgetFlag(false);
  }

  useEffect(()=>{
    if (!window.checkout) {

      window.checkout = {
        selectRecommendedProduct: function(productId) {
          selectProductById(productId);
        }
      }
    }
     // eslint-disable-next-line react-hooks/exhaustive-deps 
  },[])

  return (
      widgetFlag ?
      <Grid
        container
        className={classes.page}>

        <Grid container item className={classes.logoSpace}>
            {/* desktop logo is used on desktop. */}
            <Grid item className={classes.desktopLogo}>
              {/* replaced <DesktopLogo />  with any react component or follow similar pattern as the MobileLogo */}
              <DesktopLogo />
            </Grid>
               {/* mobile logo used on Mobile */}
            <Grid className={classes.mobileLogo}>
              {/* Replace the tag below with any react component like the DesktopLogo above or update the brand found at ../Brand/mobile-logo@2x.png */}
              <img src={MobileLogo} width='70px' height='24px' alt='logo' />
            </Grid>
         </Grid>
         <div
          item
          container
          className={classes.root}
        >
          
          <ProductDetails 
            options={products}
            selectedProduct={selectedProduct}
            selectProductById={(prodId) => {selectProductById(prodId) } }
          />
          
          <HyperWidget
            size={widgetSize}
          />
          
        </div>   
        

      </Grid>: 
      <SuccessDialog
        tokens= {chargeToken}
        open={true}
        selectedProduct={selectedProduct}
        // onClose={handleClose}
        />
  )
}




export default Checkout;