import React, { useState } from "react";
import PropTypes from "prop-types";
import Grid from "@material-ui/core/Grid";
import { useMediaQuery } from '@material-ui/core';

import color from '../styles/color';
import { useStyles } from './options.styles';
import Button from '../Button';
import Text from '../Text';
import MoreOptionUp from '../icons/MoreOptionUp';
import MoreOptionDown from '../icons/MoreOptionDown';
import OptionList from './optionList';

function ProductOptions(props) {

  const isDesktop = useMediaQuery(theme => theme.breakpoints.up('md'));

  const classes = useStyles();
  const { 
    options,
    onSelectItem,
  } = props;

  const [optionVisible, setOptionVisible] = useState(false)
  
  
  function showOptions(event){
    setOptionVisible(!optionVisible);
  }

  function renderOptionNumber(){
    if(options.length <= 0 ) {
      return;
    }
    return(
        <div className={classes.optionsCircle}>
          {options.length - 1}
        </div>
    )
  }
  function renderMoreOptions() {
    if(isDesktop){
      return (<Text 
        type='more_options'
        align='center'
        color={color.palette.moreOptions}
      >
          More Options
      </Text>);
    }
    return (
      <Button 
          buttonType="moreOptions"
          onClick={showOptions}
        >
          {renderOptionNumber()}
          More options
          {renderOptionIcon()}
      </Button>
    )
  }

  function renderOptionIcon(){
    if(optionVisible){
      return (
        <MoreOptionUp
          classes={
            {root: classes.moreOptionIconRoot}
          }
          viewBox="0 -1 14 8"
        />
      );
    }

    return (
      <MoreOptionDown
        classes={
          {root: classes.moreOptionIconRoot}
        }
        viewBox="0 -1 14 8"
      />
    );
  }

  return (
    <Grid
        container 
        item
        xs={12} 
        className={classes.root}
    >
        <Grid item xs={12} className={classes.moreOptionSpace}>
            {renderMoreOptions()}
        </Grid>

        <Grid 
          item 
          xs={12}
          className={ isDesktop || optionVisible? classes.contentOpen : classes.contentClose}
          >
            <OptionList
              options={options}
              onSelectItem={onSelectItem}
            />
        </Grid>
    </Grid>
  );
}

ProductOptions.propTypes = {
   options: PropTypes.array,
   onSelectItem:PropTypes.func,
};
 
ProductOptions.defaultProps = {
    options:[],
    onSelectItem: () => {},
};

export default ProductOptions;
