import React, { Fragment} from "react";
import PropTypes from "prop-types";
import { useMediaQuery } from '@material-ui/core';
 
import { useStyles } from './options.styles';
import Button from '../Button';

function OptionItem(props) {
   
  const isDesktop = useMediaQuery(theme => theme.breakpoints.up('md'));


  const {
    data,
    onClick,
  } = props; 

  const {
    productName,
    price,
    paymentTerms,
    selected,
  } = data;

  const classes = useStyles();
 
  function renderLabel() {
    if( isDesktop ) {
      // Order  of the label is different from mobile
      return(
        <Fragment >
      
          <span className={classes.productName}>
            {productName}
            <span className={classes.paymentTerms}>
              {paymentTerms}
            </span>
          </span>
          
          <span className={classes.productPrice}>
            {price}
          </span>

        </Fragment>
      );
    }

    return (
        <Fragment>
          <span className={classes.productPrice}>
            {price}
          </span>

          <span className={classes.productName}>
            {productName}
          </span>
          
          <span className={classes.paymentTerms}>
            {paymentTerms}
          </span>
        </Fragment>
    );

  }
  
  return (
    <Button 
      onClick={onClick}
      classes={{
          root: classes.optionItemRoot,
          customType: classes.optionItemCustomType,
      }}
      disabled={selected}
    >
      { renderLabel()}
    </Button>
  );
}

OptionItem.propTypes = {
  onClick: PropTypes.func,
};
 
OptionItem.defaultProps = {
  data: {},
  onClick:()=>{},
};

export default OptionItem;
