import React, {useState, useEffect} from 'react';
import Grid from "@material-ui/core/Grid";
import { useStyles }  from './options.styles';
import OptionItem from './optionItem';
import PropTypes from "prop-types";

function OptionList(props){

    const {
        options,
        onSelectItem,
    } = props

    const classes = useStyles();
    const [_options, updateOptions] = useState(options);

    useEffect(()=>{
        updateOptions(options);
    },[options]);

    function handleClick(index, event) {
        const selectedOpt = changeSelectedOption(index);
        if ( typeof onSelectItem === 'function') {
            onSelectItem(selectedOpt);
        }
    }

    function changeSelectedOption(index){
        const newOpts = [];
        let selected = {};
        for( let i = 0 ;  i < _options.length; i++) {
            var opt = _options[i];
            if( i === index) {
                newOpts.push({...opt, selected: true});
                selected = {...opt, selected: true};
            } else {
                newOpts.push({...opt, selected: false});
            }
        }
        updateOptions(newOpts);
        return selected;
    }

    function renderOptions(option, index){
        return( 
            <OptionItem
                key={'option_' + index}
                data={option}
                onClick={(event)=>handleClick(index,event)}
            />
        );
    }

    return (
        <Grid container className={classes.optionList}>
            {_options.map(renderOptions)}
        </Grid>
    )
}


OptionList.propTypes = {
   onSelectItem: PropTypes.func,
};
 
OptionList.defaultProps = {
    options:[],
    onSelectItem: ()=>{},
};


export default OptionList;