import { ApolloClient, createHttpLink, InMemoryCache } from '@apollo/client';
import { setContext } from '@apollo/client/link/context';
import axios from 'axios';

import { withBaseURL } from './index';


export function createApolloClient(endpointURL, options) {

    const  {
        ignoreBaseURL,
        credentials,
        token,
    } = options

    const headerOptions = options.headerOptions ? options.headerOptions : {};

    const link = createHttpLink({
        uri: ignoreBaseURL ?  endpointURL :  withBaseURL(endpointURL),
        credentials: credentials ? credentials: '',
    });

    const authLink = makeAuthLink(token, headerOptions )
    
    const client = new ApolloClient({
        link: authLink.concat(link),
        cache: new InMemoryCache()
    });
    return client;
}

export function fetchGQLRequest(endpointURL, queryParams, options = { ignoreBaseURL: false, token: '' }) {
    function execRequest(resolve,reject){
        const client =  createApolloClient(endpointURL,options);
        client
        .query(queryParams)
        .then(result => {
            resolve(result);
        })
        .catch(error => {
            reject(error)
        });
    }
    return new Promise(execRequest);
}

export function makeAuthLink( token, headerOptions )  {
    return setContext( ( _, { headers }) => {
        return {
            headers: {
                ...headers,
                ...headerOptions,
                authorization: token ? `Bearer ${token}` : '',
            }
        }
    });
};



export function fetchGQLWithAxios(endpointURL, query, options = { ignoreBaseURL: false, token: '' , headers: {} }) {
    
    const {
        token,
        headers,
        ignoreBaseURL,
    } = options;

    function execRequest(resolve,reject){
        
        const reqHeaders = {
            authorization: `Bearer ` + token,
            ...headers,
        };

        axios
        .post(
            ignoreBaseURL ?  endpointURL :  withBaseURL(endpointURL),
            query,
            {headers: reqHeaders },
        )
        .then(function (response) {
            resolve(response);
           
        })
        .catch(function (error) {
            reject(error)
        });
    }
    return new Promise(execRequest);
};