import axios from 'axios';

import {
    fetchGQLRequest, 
    fetchGQLWithAxios,
    Endpoints,
} from '../../api/index';

import {
    upsertUserQuery,
    validateOTPQuery,
    getUserProfileQuery,
    testScheduleGQL,
    restScheduleGQL,
    authenticateUserQuery,
} from './queries';


export function loadUserAPI() {
    function execRequest(resolve,reject){
        axios
        .get(Endpoints.getUser)
        .then(function (response) {
            resolve(response);
           
        })
        .catch(function (error) {
            reject(error)
        });
    }
    return new Promise(execRequest);
}

export function upsertUserAPI(fullName,mobile, email, token ) {
    return fetchGQLWithAxios(
        Endpoints.profileGQL,
        upsertUserQuery({
            input: { fullName, mobile, email },
        }),
        { 
            ignoreBaseURL: false,
            token: token,
            headers: {},
        },
    );    
}

export function  validateOTPAPI(otp, token){
    return fetchGQLWithAxios(
        Endpoints.profileGQL,
        validateOTPQuery({
            input: { otp },
        }),
        { 
            ignoreBaseURL: false,
            token: token,
            headers: {},
        },
    );    
}

//no connection mocking
export function getUserProfileAPIMOCK() {
    function execRequest(resolve,reject){
        axios
        .get('data/getUserProfile.json')
        .then(function (response) {
            resolve(response);
           
        })
        .catch(function (error) {
            reject(error)
        });
    }
    return new Promise(execRequest);
}

export function getUserProfileAPI(token) {
    /*
    console.log("Get User Profile API Token: ", token );
    return getUserProfileAPIMOCK();
    */
    
    return fetchGQLWithAxios(
        Endpoints.profileGQL,
        getUserProfileQuery( {
            filter: {
                source: token ? 'ecal' : 'unknown',
                token: token,
            },
        }),
        { 
            ignoreBaseURL: false,
            token: '',
            headers: {},
        },
    );    
    
}


export function authentifcateUserAPI(token) {
    return fetchGQLWithAxios(
        Endpoints.profileGQL,
        authenticateUserQuery( {}),
        { 
            ignoreBaseURL: false,
            token: token,
            headers: {},
        },
    );    
    
}

export function getUserDetailsAPI(token) {
    /*
    console.log("Get User Profile API Token: ", token );
    return getUserProfileAPIMOCK();
    */
    
    return fetchGQLWithAxios(
        Endpoints.profileGQL,
        authenticateUserQuery( {}),
        { 
            ignoreBaseURL: false,
            token: token,
            headers: {},
        },
    );    
    
}

export function testScheduleGQLAPI(data) {
    return fetchGQLRequest(
        Endpoints.testScheduleGQL,
        testScheduleGQL( { filter: { ids:['59150d50a736423b25bf9302'] } }),
        { 
            ignoreBaseURL: true,
            token: 'eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJwdWJsaXNoZXJfaWQiOjEyMjMzLCJwdWJsaXNoZXJJZCI6MTIyMzMsIm9yZ2FuaXNhdGlvbklkIjo0MTQ2LCJlbWFpbCI6InN1Y2Nlc3MrNjI0MTVhZDljZjFiMjA2MkBzaW11bGF0b3IuYW1hem9uc2VzLmNvbSIsImlkIjoxMjIzMywiaWF0IjoxNjAyNzQzMTI5LCJvcmlnX2lhdCI6MTYwMjc0MzEyOSwiZXhwIjoxNjAyNzQ0OTI5fQ._IHGAZMTwBFWR43Pn5tCJ2XeQNkSZkpGbvIR0uaUdOM',
        }
    )
}

export function restGQLAPI(data) {  
    return fetchGQLWithAxios(
        Endpoints.testScheduleGQL,
        restScheduleGQL( { filter: { ids:['59150d50a736423b25bf9302'] } }),
        {
            ignoreBaseURL: true,
            token: 'eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJwdWJsaXNoZXJfaWQiOjEyMjMzLCJwdWJsaXNoZXJJZCI6MTIyMzMsIm9yZ2FuaXNhdGlvbklkIjo0MTQ2LCJlbWFpbCI6InN1Y2Nlc3MrNjI0MTVhZDljZjFiMjA2MkBzaW11bGF0b3IuYW1hem9uc2VzLmNvbSIsImlkIjoxMjIzMywiaWF0IjoxNjAyNzQ1MTcyLCJvcmlnX2lhdCI6MTYwMjc0NTE3MiwiZXhwIjoxNjAyNzQ2OTcyfQ.sIdWgzgMsMIrSPnIh0u2jU4mRv2JM_WPEHOldB4Dz7k',
        },
    );
}