import React from "react";
import PropTypes from "prop-types";
import classNames from "classnames";
import Button from "@material-ui/core/Button";
import useStyles from "./button.styles";

export const ButtonTypes = {
  HYPER: 'hyper',
  PRIMARY: "primary",
  SECONDARY: "secondary",
  THIRD_PARTY: "thirdParty",
  ICON_BUTTON: "iconButton",
  TEXT_INPUT: "textInput",
  MORE_OPTIONS: 'moreOptions',
  LINK: 'link',
  LINK_BOLD: 'linkBold',
};

function HyperButton(props) {
  
  const defaultClasses = useStyles();
  const { className, buttonType, smBtn, classes, ...otherProps } = props;

  function selectRoot() {

    if( classes && classes.root) {
        return classes.root;
    }

    if (defaultClasses[buttonType + "Root"] ) {
      return defaultClasses[buttonType + "Root"];
    }

    return defaultClasses.root;
  }

  function selectText() {
    if( classes && classes.text) {
        return classes.text;
    }

    if (defaultClasses[buttonType + "Text"] ) {
      return defaultClasses[buttonType + "Text"];
    }

    return defaultClasses.text;
  }

  function selectClassName(){
      if( classes && classes.customType) {
        return classes.customType;
      }
      return defaultClasses[buttonType];
  }
  return (
    <Button
      classes={
          { 
            root: selectRoot(),
            text: selectText(),
          }
      }
      className={classNames([
          selectClassName(), 
          ...className, 
          { smallBtn: smBtn },
        ])}
        {...otherProps}
    />
  );
}

HyperButton.propTypes = {
    /*
    buttonType: PropTypes.oneOf([...Object.keys(ButtonTypes), ""]),
    */
    className: PropTypes.oneOfType([
      PropTypes.string,
      PropTypes.arrayOf(PropTypes.string)
    ]),
    smBtn: PropTypes.bool,
    children: PropTypes.array,
    classes: PropTypes.object,
    disabled: PropTypes.bool,
};
 
HyperButton.defaultProps = {
  className: [],
  buttonType: ButtonTypes.PRIMARY,
  smBtn: false,
  disabled: false,
};

export default HyperButton;
