import React from 'react';
import PropTypes from 'prop-types'; 
import classnames from 'classnames';
import Grid from '@material-ui/core/Grid';
import TextField from '@material-ui/core/TextField';

import cards from '../icons/creditcards';
import { useStyles } from './creditCardInput.styles';
import useCreditcardBehavior from './useCreditcardBehavior';

 

export const CardType = {
    MASTERCARD: 'mastercard',
    VISA: 'visa',
    OTHERS: '',
};

function CreditCardInput(props) {

    const classes = useStyles();
     
    const { 
        className,
        cardType,
        numberPlaceholder, 
        datePlaceholder,
        codePlaceholder,
        cardNumber,
        expiryDate,
        securityCode,
        onChange,
        onCardNumberChange,
        onSecurityCodeChange,
        onDateChange,
        ...otherProps
    } = props;

    const {
        handleNumberChange,
        handleDateChange,
        handleCodeChange,
        handleDateKeyPress,
        handleCodeKeyPress,
        handleNumberKeyPress,
        _cardNumber,
        _expiryDate,
        _securityCode,

    } = useCreditcardBehavior({
        cardNumber,
        expiryDate,
        securityCode,
        onChange,
        onCardNumberChange,
        onSecurityCodeChange,
        onDateChange,
    });

    function renderCardIcon(){
        switch (cardType) {
            case 'mastercard':
                return (<cards.Mastercard />);
            
            case '':
            default:
                return <cards.DefaultCreditcard  />
        }     
    }

    return (
        <Grid container  
            className={classnames([classes.inputContainer, className])}
        >   
            <Grid container item xs={8}
                    className={classnames([classes.childContainer])}
                >  
                <Grid item className={classes.iconContainer} >
                    {
                    renderCardIcon()
                    }
                </Grid>
                <Grid item>
                    <TextField
                        type='text'
                        value={_cardNumber}
                        placeholder={numberPlaceholder}
                        onChange={handleNumberChange}
                        onKeyPress={handleNumberKeyPress}
                        InputProps={{ 
                            disableUnderline: true,  
                            classes:{
                                root: classes.MuiInputBaseRoot,
                                input: classes.MuiInputBaseInput,
                            }     
                        }}
                        {...otherProps}
                    />
                </Grid>
            </Grid>
           
            <Grid item xs={2}>
                <TextField  
                        type='text'
                        value={_expiryDate}
                        onChange={handleDateChange}
                        onKeyPress={handleDateKeyPress}
                        placeholder={datePlaceholder}
                        InputProps={{ 
                            disableUnderline: true,   
                            classes:{
                                root: classes.MuiInputBaseRoot,
                                input: classes.MuiInputBaseInput,
                            }         
                        }}
                        {...otherProps}
                    />
            </Grid>

            <Grid item xs={2}>
                <TextField  
                    type='password'
                    value={_securityCode}
                    onChange={handleCodeChange}
                    onKeyPress={handleCodeKeyPress}
                    placeholder={codePlaceholder}
                    InputProps={{ 
                        disableUnderline: true,   
                        classes:{
                            root: classes.MuiInputBaseRoot,
                            input: classes.MuiInputBaseInput,
                        }         
                    }}
                    {...otherProps}
                />
            </Grid>
            
        </Grid>
        
       
    );
}

CreditCardInput.propTypes = {
    onChange: PropTypes.func,
    onCardNumberChange: PropTypes.func,
    numberPlaceholder: PropTypes.string,
};

CreditCardInput.defaultProps = {
    onChange: () => {},
    onCardNumberChange: () => {},
    onDateChange: () => {},
    onSecurityCodeChange: () => {},
    numberPlaceholder: 'Card number',
    datePlaceholder: 'MM/YY',
    codePlaceholder: 'CVC',

    cardNumber: '',
    expiryDate: '',
    securityCode: '',
    cardType: '',
};

export default CreditCardInput;