import React from "react";
import PropTypes from "prop-types";
import classNames from "classnames";
import Button from "@material-ui/core/Button";
import useStyles from "./hyperButton.styles";
import HyperPay from '../animations/HyperPay';
import color from '../styles/color';
import  Lock  from '../icons/Lock';
import  CreditCard from '../icons/imgs/ZipPay'
function HyperButton(props) {
  
  const defaultClasses = useStyles();
  const { 
    className,
    disabled,
    buttonType,
    smBtn,
    classes,
    children, 
    withLock,
    customIconType,
    ...otherProps
  } = props;

  function selectRoot() {

    if( classes && classes.root) {
        return classes.root;
    }

    return defaultClasses.root;
  }


  function renderIcon(){
    if (customIconType) {
      console.log("renderIcon()", customIconType);

      if (customIconType === 'creditCard') {
        console.log("")
        console.log("return credit card");
        return  <CreditCard />;
      }
      return  <CreditCard />;
    }
    if (withLock) {
      return (<Lock className={defaultClasses.icon}  color={ disabled ? color.buttons.labelDisable : '' }  />);
    }
    return
  }


  return (
    <Button
      startIcon={renderIcon()}
      classes={
          { 
            root: selectRoot(),
            text: defaultClasses.text,
          }
      }
      className={classNames([
         defaultClasses.hyper, 
          ...className, 
        ])}
        {...otherProps}
    >
      <div className={defaultClasses.playerSpan}>
        <HyperPay
        />
      </div>
      <span className={defaultClasses.text}>
        {children}
      </span>
    </Button>
  );
}

 
HyperButton.propTypes = {
   
    className: PropTypes.oneOfType([
      PropTypes.string,
      PropTypes.arrayOf(PropTypes.string)
    ]),
    children: PropTypes.array,
    customIconType: PropTypes.string,
    classes: PropTypes.object,
    disabled: PropTypes.bool,
    withLock: PropTypes.bool,
};
 
HyperButton.defaultProps = {
  className: [],
  customIconType: '',
  disabled: false,
  withLock: false,
};

export default HyperButton;
