import React, { createRef } from 'react';
import PropTypes from 'prop-types'; 
import classnames from 'classnames';
import Grid from '@material-ui/core/Grid';
import TextField from '@material-ui/core/TextField';
 
import { useStyles } from './otpInput.styles';
import useOTPBehavior from './useOTPBehavior';

function OTPInput(props) {


    const classes = useStyles();
     
    const {    
        onChange,
        otpLength, 
    } = props;
   

    const {
        addInputRef,
        clearInputRefs,
        handleKeyPress,
        handleKeyUp,
        handleChange,
        handlePaste,
        arrVal,
        observeForFocus,
    } = useOTPBehavior({
        onChange,
        otpLength,
    });
    
    function onLoad(event){
        console.log("Input Loaded: ", event.target);
    }
    function renderInputs(){
        const jsx = [];
        clearInputRefs();
        for ( let i = 0; i < otpLength; i++) {
            const ref = createRef();
            addInputRef(ref);
            const itemClassnames = [classes.inputSize];
            if( i !== 0 ) itemClassnames.push(classes.inputSpace);
            jsx.push(
                (<TextField
                    type='tel'
                    id={i === 0 ? 'otp_input_first' : null}
                    onLoad={onLoad}
                    value={arrVal[i]}
                    className={classnames(itemClassnames)}
                    onKeyPress={(event)=>handleKeyPress(i,event)}
                    onChange={(event)=>handleChange(i,event)}
                    onKeyUp={(event)=>handleKeyUp(i,event)}
                    onPaste={handlePaste}
                    InputProps={{ 
                        inputMode:'decimal',
                        disableUnderline: true,  
                        classes:{
                            root: classes.MuiInputBaseRoot,
                            input: classes.MuiInputInput,
                        } 
                    }}
                    inputRef={ref}
                />)
            );
        }
        observeForFocus();
        return jsx;
    }
    return (
        <Grid container  
            className={classnames([classes.inputContainer])}
        >   
            {renderInputs()}
        </Grid>
    );
}

OTPInput.propTypes = {
    otpLength: PropTypes.number,
    onChange: PropTypes.func,
}
OTPInput.defaultProps = {
    otpLength: 5,
    onChange: () => {},
};

export default OTPInput;