import {useState, useEffect} from 'react';

function useOTPBehavior(props){
    const {
        onChange,
        otpLength,
    } = props;

    const [, setKeyPressed] = useState('');

    const [_value, setValue] = useState("");
    const [arrVal, setArrVal] = useState([]);
    const [inputHasFocus, setInputHasFocus] = useState(false);
    let inputRefs = [];
    function clearInputRefs () {
        inputRefs = [];
    }

    function addInputRef(ref) {
        inputRefs.push(ref);
    }

    function setInitialFocus(__ref, index) {
        if (index <= 0 && !inputHasFocus) {
            console.log("setInitialFocus(): ", __ref);
            var ref = __ref;
            function focus() {
               if (ref && ref.current ) {
                    ref.current.focus();
                    setInputHasFocus(true);
                }
            }
            setTimeout(focus, 100);
        }
    }

    function observeForFocus() {
        if (inputHasFocus) return;
        function watchInput() {
            const input = document.getElementById("otp_input_first");
            if (input) {
                setInputHasFocus(true);
                input.focus();
            } else {
                setTimeout(watchInput,100)
            }
        }
        watchInput();
    }

    function handleKeyUp(index, event) {
        if (((event.which >= 47 && event.which < 58) || event.keyCode === 8) === false ) {
            event.preventDefault();
            return false;
        }

        if (event.keyCode === 8 && event.target.value === '' ) {
            const ref = inputRefs[index - 1];
            if ( ref !== undefined && ref.current !== undefined ) {
                ref.current.focus();
                return true;
            } 
            return true;
        }
        
        const ref = inputRefs[index + 1];
        if ( ref !== undefined && ref.current !== undefined ) {
            ref.current.focus();
        } 

    }

    function handleKeyPress(index, e) {
        if(e.target.value.length >= 1) {
            e.preventDefault();
            return false;
        }
     
        if ( (e.which >= 47 && e.which < 58) === false ) {
            e.preventDefault();
            return false;
        }
     
        updateKey(e.key ||  e.keyCode || e.charCode );
    }

    function handleChange(index, e){
        arrVal[index] = e.target.value;
        setValue(arrVal.join(''));
    }

    function updateKey(key) {
        setKeyPressed(key)
    }

    function handlePaste (e) {
        const text = e.clipboardData.getData('Text').split("");
        const regEx = /[0-9]/gi;
        const newArrVal = []; 
        for ( let i = 0; i < otpLength; i++ ) {
            if(text[i].match(regEx) === null ) {
                newArrVal.push('');
            } else {
                newArrVal.push(text[i]);
            }
        }
        setArrVal(newArrVal);
        setValue(newArrVal.join(''));
        e.preventDefault();
        return false;
    }

    useEffect(()=>{
        if( typeof onChange === 'function') {
            onChange(_value);
        }
    // eslint-disable-next-line react-hooks/exhaustive-deps 
    },[_value]);
  
    return {
        handleKeyPress,
        handleChange,
        handleKeyUp,
        addInputRef,
        handlePaste,
        clearInputRefs ,
        setInitialFocus,
        observeForFocus,
        arrVal,
    }
}

export default useOTPBehavior;