import React from "react";
import PropTypes from "prop-types";
import Grid from "@material-ui/core/Grid";
 
import color from '../styles/color';
import { useStyles } from './productCard.styles';
import Text from '../Text';
import ProductOptions from '../ProductOptions';

function ProductCard(props) {

  const {
    name,
    details,
    price,
    options,
    onSelectItem,
    recommended,
    paymentTerms,
  } = props; 

  const classes = useStyles();

  function renderRecommended(){
    if( recommended ) {
        return  (<div className={classes.recommendedBar}>Recommended</div>);
    }
    return;
  }

  function renderTerms(){
      if(paymentTerms === 'Annually'){
        return (<span className={classes.terms}> / y</span>);
      }
      return (<span className={classes.terms}> / m</span>);
  }
  
function nameSuffix () {
        if(paymentTerms === 'Annually'){
        return ' annual subscription';
      }
      return ' monthly subscription';  
  }

  return (
    <Grid
        container 
        item
        xs={12} 
      
        className={classes.productCardRoot}
    >
        <Grid
            container
            item
            className={classes.nameRoot}
        >
            <Grid item xs={12} md={7} >
                <Text 
                    className={classes.name}
                    type="heading"
                    align='center'
                    color={color.typography.main} > {name + nameSuffix()}   </Text>
            </Grid>
            <Grid 
                item
                xs={12}
                className={classes.detailsRoot}>
                <Text 
                    type="body"
                    className={classes.details}
                    color={color.typography.subtext}
                    > {details} </Text>
            </Grid>
        </Grid>

        <Grid 
            container
            item
            xs={4}
            md={12}
            className={classes.priceRoot}>
                <Text 
                    className={classes.price}
                    type="price"
                    color={color.typography.main} > 
                    {price}{renderTerms()}
                </Text>
                { renderRecommended() }
        </Grid>

        <ProductOptions
            options={options}
            onSelectItem={onSelectItem}
        />

    </Grid>
  );
}

ProductCard.propTypes = {
    name: PropTypes.string,
    details: PropTypes.string,
    price: PropTypes.string,
    options: PropTypes.array,
    onSelectItem: PropTypes.func,
    recommended: PropTypes.bool,
    paymentTerms: PropTypes.string,
};
 
ProductCard.defaultProps = {
    name: 'Product Name',
    details: 'Product Details',
    price: '$28.00',
    paymentTerms: 'monthly',
    options:[],
    recommended: false,
    onSelectItem:()=>{},
};

export default ProductCard;
