import React from 'react';
import PropTypes from 'prop-types';
import classnames from 'classnames';
import Grid from  '@material-ui/core/Grid';
import InputAdornment from  '@material-ui/core/InputAdornment'
import { makeStyles} from '@material-ui/core/styles';

import TextField from '@material-ui/core/TextField'; 
import LockField from '../icons/imgs/LockField';
import Button, { ButtonTypes } from   '../Button';
import styles from './textInput.styles';
import useTextInputHandlers from './useTextInputHandler';

const useStyles = makeStyles(styles);

export const TextInputType = {
    EMAIL: 'email',  
    NAME: 'name',
    TEXT: 'text',
    NUMBER: 'number',
    PHONE: 'phone',
};

function TextInput(props) {

    const classes = useStyles();
    const {
        label,
        className,
        onChange,
        value,
        withEditButton,
        withLockIcon,
        editButtonLabel,
        error,
        type,
        invalidCharPattern,
        ...otherProps
    } = props;


    const {
        handleChange,
        _value,
        _inputRef,
    } = useTextInputHandlers( { onChange , value, type, invalidCharPattern});
    
    function getInputMode() { 
       switch(type) {
           case TextInputType.NUMBER: 
                return  'decimal';
            
           case TextInputType.EMAIL: 
                return  'email';
            

            case TextInputType.PHONE: 
                return  'tel';

           case TextInputType.TEXT:
           default: 
                return 'search'
       }
    }

    function renderEndAdornment() {
        
        if ( withLockIcon === true ) {
            /*
            className={classes.lock}
                    pathClassName={classes.lockPath}
            */

            return(
                <Grid className={classes.lockSpace}>
                    <LockField  />
                </Grid>
            )
        }
        if(withEditButton === true ) {
            return (
                <Button
                    buttonType={ButtonTypes.TEXT_INPUT}
                >
                 {editButtonLabel}
              </Button>
  
            )
        }

        return;
    }

    function inputClassname(){
        if( error ) {
            return classnames([classes.input, classes.error]);
        }
        return classnames([classes.input]);
    }

   

    return (
        <TextField  
            type='text'
            
            onChange={handleChange}
            onFocus={(e) => {
                /*
                console.log('');
                console.log('');
                console.log('input focus()....', e);    
                */
            }}

            onBlur={(e) => {
                /*
                console.log('');
                console.log('input blur()....', e);  
                */  
            }}
            onKeyPress={(e)=> {
                /*
                console.log("");
                console.log("key pressed.... ", e);
                */
            }}

            onKeyDown={(e)=> {
                /*
                console.log("" );
                console.log("key down.... ", e);
                */
            }}

           
            value={_value}
            
            InputProps={{
             
                inputMode: getInputMode(),
                disableUnderline: true,
                startAdornment: (<InputAdornment position="start"> {label} </InputAdornment>),
                endAdornment: renderEndAdornment(),
                className: classes.MuiInputBaseRoot,
                classes:{ input: inputClassname() },
                           
            }}
            
            inputRef={_inputRef}
            
            {...otherProps}
        />
    );
}

TextInput.propTypes = {
    label: PropTypes.string,
    type: PropTypes.string,
    invalidCharPattern: PropTypes.any,
};

TextInput.defaultProps = {
    label: '',
    type: TextInputType.TEXT,
    withEditButton: false,
    editButtonLabel: "Edit",
    withLockIcon: false,
    onChange: () => {}, 
    value:"",
    error: false,
    invalidCharPattern: null,
};

export default TextInput;