import { useState, createRef, useEffect } from 'react';

function useTextInputHandler(data) {

    const {
        onChange,
        value,
        onEditClick,
        inputRef,
        invalidCharPattern,
    } = data;

    const [_value, setValue] = useState(value);
    const [_inputRef] = useState(inputRef || createRef());
    

    function handleChange(event) {
        if(invalidCharPattern) {
            const reducedValue = event.target.value.replace( invalidCharPattern, '');
            //console.log("Reduced Value: ", reducedValue);
            setValue(reducedValue);
            return;
        }
        setValue( event.target.value);
    }



    function handleEditClick(event){
        setValue("");
        if( _inputRef !== null && _inputRef.current !== null ) {
            //_inputRef.current.focus();
        }
        
        if ( typeof onEditClick === 'function') {
            onEditClick(event);
        }
    }

    useEffect(()=>{
        setValue(value);
    }, [value]);

    useEffect(()=>{
        if (typeof onChange ===  'function') {
            onChange(_value);
        }
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [_value]);
 
    return {
        _value,
        handleChange,
        handleEditClick,
        _inputRef,
    }
}
export default useTextInputHandler;